#!perl
use 5.006;
use strict;
use warnings;
use Test::More;

plan tests => 1;

BEGIN {
    use_ok( 'Merge::CodeBlock' ) || print "Bail out!\n";
}

diag( "Testing Merge::CodeBlock $Merge::CodeBlock::VERSION, Perl $], $^X" );
